#include <cstdio>
#include <cstdlib>
#include <vector>
#include <algorithm>
#include <cmath>
#include <queue>
#include <list>
using namespace std;
#define REP(i,n)	for(int i=0,_n=(n);i<_n;++i)
#define REPD(i,n)	for(int i=(n-1);i>=0;--i)
#define FOR(i,s,k)	for(int i=(s),_k=(k);i<=_k;++i)
#define FORD(i,s,k)	for(int i=(s),_k=(k);i>=_k;--i)
#define FORE(it,q)	for(__typeof((q).begin())it=(q).begin();it!=(q).end();++it)
#define FORED(it,q)	for(__typeof((q).rbegin())it=(q).rbegin();it!=(q).rend();++it)
#define FOREACH(it,f,l)	for(__typeof(f)it=f;it!=l;++it)
#define FOREACHD(it,f,l)	for(__typeof(f)it=l;it--!=f;)

const int max_n = 2000;
const int max_r = 10000;
const double eps = 0.0000001;

struct xy {
	int x;
	int y;
	xy(int _x = 0, int _y = 0) : x(_x), y(_y) {}
};

struct point {
	double x;
	double y;
	point(double _x = 0.0, double _y = 0.0) : x(_x), y(_y) {}
	bool operator < (const point &b) const {
		if (!(y < 0)) {
			if (b.y < 0) return true;
			if (!(x < 0) && b.x < 0)
				return true;
			if (x < 0 && !(b.x < 0))
				return false;
		} else {
			if (!(b.y < 0)) return false;
			if (x < 0 && !(b.x < 0))
				return true;
			if (!(x < 0) && b.x < 0)
				return false;
		}
		double v = x*b.y - b.x*y;
		if (v < 0) return false;
		if (v > 0) return true;
		return false;
	}
};

struct event {
	point p;
	int op;
	int id;
	event(const point &_p, int _op, int _id) : p(_p), op(_op), id(_id) {}
	bool operator < (const event &b) const  {
		if (p < b.p) return true;
		if (b.p < p) return false;
		return (op == 1 && b.op == -1);
	}
};

xy P[max_n];
bool C[max_n];
int n, r;

double dist(const xy &p1, const xy &p2) {
	return sqrt((double)((p1.x-p2.x)*(p1.x-p2.x) + (p1.y-p2.y)*(p1.y-p2.y)));
}

point circle_centre1(const xy &p1, const xy &p2) {
	int dfy = p2.y-p1.y;
	int dfx = p2.x-p1.x;
	double alfa1 = atan2(dfy, dfx);
	double d = dist(p1, p2);
	double x = d/2;
	double y = r*r - d*d/4;
	double alfa2 = atan2(-y, x);
	double alfa = alfa1+alfa2;
	point p;
	p.x = cos(alfa)*r;
	p.y = sin(alfa)*r;
	return p;
}

point circle_centre2(const xy &p1, const xy &p2) {
	int dfy = p2.y-p1.y;
	int dfx = p2.x-p1.x;
	double alfa1 = atan2(dfy, dfx);
	double d = dist(p1, p2);
	double x = d/2;
	double y = r*r - d*d/4;
	double alfa2 = atan2(y, x);
	double alfa = alfa1+alfa2;
	point p;
	p.x = cos(alfa)*r;
	p.y = sin(alfa)*r;
	return p;
}

bool testcase() {
	
	scanf("%d %d", &n, &r);
	if (n == 0 && r == 0) return 0;
	REP(i,n)
		scanf("%d %d", &P[i].x, &P[i].y);
	int mx = 0;
	REP(pi,n) {
		list<event> Q;
		REP(i,n) if (i != pi && dist(P[pi], P[i]) <= 2*r + eps) {
			point o1 = circle_centre1(P[pi], P[i]);
			point o2 = circle_centre2(P[pi], P[i]);
//			printf("%d  %lf %lf   %lf %lf\n", i, o1.x, o1.y, o2.x, o2.y);
			Q.push_back(event(o1, 1, i));
			Q.push_back(event(o2, -1, i));
		}
		Q.sort();
		REP(i,n) C[i] = false;
		while (Q.front().op == -1) {
			Q.push_back(Q.front()); Q.pop_front();
		}
		int cnt = 1;
		event e = Q.front(); Q.pop_front(); Q.push_back(e);
		int s = e.id;
		C[s] = true;
		do {
			e = Q.front(); Q.pop_front(); Q.push_back(e);
			if (e.op == 1) {
				++cnt; C[e.id] = true;
				mx >?= cnt;
			} else if (e.op == -1 && C[e.id]) {
				--cnt;
				C[e.id] = false;
			}
		} while (e.id != s);
		do {
			e = Q.front(); Q.pop_front(); Q.push_back(e);
			if (e.op == 1) {
				++cnt; C[e.id] = true;
				mx >?= cnt;
			} else if (e.op == -1 && C[e.id]) {
				--cnt;
				C[e.id] = false;
			}
		} while (e.id != s);	
	}
	printf("It is possible to cover %d points.\n", mx+1);
	return 1;
}


int main() {
	while(testcase());
	return 0;
}

